.. collective.templates documentation master file, created by
   sphinx-quickstart on Sun Apr 19 20:00:13 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to collective.templates's documentation!
================================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:


   installation.rst
   configuration.rst
   addnewtemplatecenter.rst
   addnewtemplateproject.rst
   publishtemplateproject.rst
   messaging.rst
   contacttotemplateproject.rst



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
